import { ParsedModel, Token, TokenType } from './types';
import { Options } from './options';
export interface ConsumerState {
    /** Original source code to parse */
    text: string;
    /** Consumed tokens */
    tokens: Token[];
    /** Accumulated clean text content of XML document */
    content: string;
    hasContent: boolean;
    prev: number;
    offset: number;
    options: Options;
}
export interface Consumer {
    /**
     * @param token A token to consume
     */
    consume(token: Token): void;
    /**
     * @param name Name of the token for identification
     * @param type Token type
     * @param start Location of token start in source code
     * @param end Location of token end in source code
     */
    consume(name: string, type: TokenType, start: number, end: number): void;
    finalize(end?: number): ParsedModel;
}
/**
 * Parses given XML source into internal model for diff
 */
export default function parse(text: string, options?: Options): ParsedModel;
/**
 * Creates XML markup consumer for given text. Returns object with `consume` function
 * that should receive markup tokens and `finalize` function to produce final
 * document model
 * @param text Original source code being parsed
 * @param baseStart Starting location in `text` where XML is consumed
 * @param baseEnd Ending location in `text` until XML is consumed
 */
export declare function createConsumer(text: string, options?: Options): Consumer;
